@@ -84,7 +84,7 @@ function getSettings(schemaId, path) {
     const GioSSS = Gio.SettingsSchemaSource;
     let schemaSource;
 
-    if (pkg.moduledir != pkg.pkgdatadir) {
+    if (!pkg.moduledir.startsWith('resource://')) {
         // Running from the source tree
         schemaSource = GioSSS.new_from_directory(pkg.pkgdatadir,
                                                  GioSSS.get_default(),
@@ -146,3 +146,8 @@ function normalizeCasefoldAndUnaccent(str) {
      */
     return str.replace(/[\u0300-\u036f]|[\u1dc0-\u1dff]|[\u20d0-\u20ff]|[\ufe20-\ufe2f]/, '');
 }
+
+function assertEqual(one, two) {
+    if (one != two)
+        throw Error('Assertion failed: ' + one + ' != ' + two);
+}
