@@ -52,6 +52,7 @@ const NewLocationController = new Lang.Class({
         dialog.set_default_response(Gtk.ResponseType.OK);
 
         dialog.connect('response', Lang.bind(this, this._onResponse));
+        entry.connect('notify::location', Lang.bind(this, this._locationChanged));
 
         this._dialog = dialog;
         this._entry = entry;
@@ -59,6 +60,7 @@ const NewLocationController = new Lang.Class({
 
     run: function() {
         this._dialog.show();
+        this._locationChanged(this._entry);
     },
 
     _onResponse: function(dialog, response) {
@@ -72,6 +74,10 @@ const NewLocationController = new Lang.Class({
             return;
 
         this._worldModel.addLocation(location);
+    },
+
+    _locationChanged: function(entry) {
+	this._dialog.set_response_sensitive(Gtk.ResponseType.OK, entry.location != null);
     }
 });
 
@@ -140,7 +146,7 @@ const MainWindow = new Lang.Class({
         let selectDone = builder.get_object('done-button');
         this._pageWidgets[Page.WORLD].push(selectDone);
 
-        let selectionBarRevealer = builder.get_object('selection-bar-revealer');
+        let selectionBar = builder.get_object('selection-bar');
         let selectionMenu = builder.get_object("selection-menu");
 
         this._selectionMenuButton = builder.get_object('selection-menu-button');
@@ -180,7 +186,7 @@ const MainWindow = new Lang.Class({
                                GObject.BindingFlags.INVERT_BOOLEAN);
         iconView.bind_property('selection-mode', selectDone, 'visible',
                                GObject.BindingFlags.SYNC_CREATE);
-        iconView.bind_property('selection-mode', selectionBarRevealer, 'reveal-child',
+        iconView.bind_property('selection-mode', selectionBar, 'visible',
                                GObject.BindingFlags.SYNC_CREATE);
         this._worldView.bind_property('empty', this.lookup_action('selection-mode'), 'enabled',
                                       GObject.BindingFlags.SYNC_CREATE |
